//+------------------------------------------------------------------+
//|                                                        kkkkk.mq5 |
//|                        Copyright 2013, MetaQuotes Software Corp. |
//|                                              http://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2013, MetaQuotes Software Corp."
#property link      "http://www.mql5.com"
#property version   "1.00"
//+------------------------------------------------------------------+
//| Include                                                          |
//+------------------------------------------------------------------+
#include <Expert\Expert.mqh>
//--- available signals
#include <Expert\MySignal\CSignalIchimoku.mqh>
//--- available trailing
#include <Expert\Trailing\TrailingNone.mqh>
//--- available money management
#include <Expert\Money\MoneyFixedLot.mqh>
//+------------------------------------------------------------------+
//| Inputs                                                           |
//+------------------------------------------------------------------+
//--- inputs for expert
input string Expert_Title                        ="kkkkk"; // Document name
ulong        Expert_MagicNumber                  =26989;   // 
bool         Expert_EveryTick                    =false;   // 
//--- inputs for main signal
input int    Signal_ThresholdOpen                =10;      // Signal threshold value to open [0...100]
input int    Signal_ThresholdClose               =10;      // Signal threshold value to close [0...100]
input double Signal_PriceLevel                   =0.0;     // Price level to execute a deal
input double Signal_StopLevel                    =50.0;    // Stop Loss level (in points)
input double Signal_TakeLevel                    =50.0;    // Take Profit level (in points)
input int    Signal_Expiration                   =4;       // Expiration of pending orders (in bars)
input int    Signal_Ichimoku_My_TenkanSenPeriod  =9;       // CSignalIchimoku(9,26,52,30,...) Period of TenkanSen
input int    Signal_Ichimoku_My_KijunSenPeriod   =26;      // CSignalIchimoku(9,26,52,30,...) Period KijunSen
input int    Signal_Ichimoku_My_SenkouSpanBPeriod=52;      // CSignalIchimoku(9,26,52,30,...) PeriodSenkouSpanB
input int    Signal_Ichimoku_StopLoss            =30;      // CSignalIchimoku(9,26,52,30,...) 
input int    Signal_Ichimoku_TakeProfit          =100;     // CSignalIchimoku(9,26,52,30,...) 
input double Signal_Ichimoku_Weight              =1.0;     // CSignalIchimoku(9,26,52,30,...) Weight [0...1.0]
//--- inputs for money
input double Money_FixLot_Percent                =10.0;    // Percent
input double Money_FixLot_Lots                   =0.1;     // Fixed volume
//+------------------------------------------------------------------+
//| Global expert object                                             |
//+------------------------------------------------------------------+
CExpert ExtExpert;
//+------------------------------------------------------------------+
//| Initialization function of the expert                            |
//+------------------------------------------------------------------+
int OnInit()
  {
//--- Initializing expert
   if(!ExtExpert.Init(Symbol(),Period(),Expert_EveryTick,Expert_MagicNumber))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing expert");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Creating signal
   CExpertSignal *signal=new CExpertSignal;
   if(signal==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating signal");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//---
   ExtExpert.InitSignal(signal);
   signal.ThresholdOpen(Signal_ThresholdOpen);
   signal.ThresholdClose(Signal_ThresholdClose);
   signal.PriceLevel(Signal_PriceLevel);
   signal.StopLevel(Signal_StopLevel);
   signal.TakeLevel(Signal_TakeLevel);
   signal.Expiration(Signal_Expiration);
//--- Creating filter CSignalIchimoku
   CSignalIchimoku *filter0=new CSignalIchimoku;
   if(filter0==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter0");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
   signal.AddFilter(filter0);
//--- Set filter parameters
   filter0.My_TenkanSenPeriod(Signal_Ichimoku_My_TenkanSenPeriod);
   filter0.My_KijunSenPeriod(Signal_Ichimoku_My_KijunSenPeriod);
   filter0.My_SenkouSpanBPeriod(Signal_Ichimoku_My_SenkouSpanBPeriod);
   filter0.StopLoss(Signal_Ichimoku_StopLoss);
   filter0.TakeProfit(Signal_Ichimoku_TakeProfit);
   filter0.Weight(Signal_Ichimoku_Weight);
//--- Creation of trailing object
   CTrailingNone *trailing=new CTrailingNone;
   if(trailing==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating trailing");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Add trailing to expert (will be deleted automatically))
   if(!ExtExpert.InitTrailing(trailing))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing trailing");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Set trailing parameters
//--- Creation of money object
   CMoneyFixedLot *money=new CMoneyFixedLot;
   if(money==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating money");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Add money to expert (will be deleted automatically))
   if(!ExtExpert.InitMoney(money))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing money");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Set money parameters
   money.Percent(Money_FixLot_Percent);
   money.Lots(Money_FixLot_Lots);
//--- Check all trading objects parameters
   if(!ExtExpert.ValidationSettings())
     {
      //--- failed
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Tuning of all necessary indicators
   if(!ExtExpert.InitIndicators())
     {
      //--- failed
      printf(__FUNCTION__+": error initializing indicators");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- ok
   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Deinitialization function of the expert                          |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
   ExtExpert.Deinit();
  }
//+------------------------------------------------------------------+
//| "Tick" event handler function                                    |
//+------------------------------------------------------------------+
void OnTick()
  {
   ExtExpert.OnTick();
  }
//+------------------------------------------------------------------+
//| "Trade" event handler function                                   |
//+------------------------------------------------------------------+
void OnTrade()
  {
   ExtExpert.OnTrade();
  }
//+------------------------------------------------------------------+
//| "Timer" event handler function                                   |
//+------------------------------------------------------------------+
void OnTimer()
  {
   ExtExpert.OnTimer();
  }
//+------------------------------------------------------------------+
